Structs
- Execution
Results - Results of a circuit execution.
- Return
Values - The decoded
returnwitnesses.
Functions
- check_
witness - Compare return values to expectations, returning errors if something unexpected was returned.
- execute
- Execute a circuit and return the output witnesses.
- input_
value_ to_ string - save_
and_ check_ witness - Print some information and save the witness if an output directory is specified, then checks if the expected return values were the ones we expected.
- save_
witness - Save the witness stack to a file.
- show_
diagnostic - Print an error stack trace, if possible.